:py:mod:`piel.models.frequency.photonic.directional_coupler_real`
=================================================================

.. py:module:: piel.models.frequency.photonic.directional_coupler_real
